// The contents of this file are subject to the Mozilla Public License Version 1.1
// (the "License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
// 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
// WARRANTY OF ANY KIND, either express or implied. See the License for the specific
// language governing rights and limitations under the License.
// 
// The Original Code is the Venice Web Communities System.
// 
// The Initial Developer of the Original Code is Eric J. Bowersox <erbo@ricochet.com>,
// for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
// Copyright (C) 2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
// 
// Contributor(s): 

importPackage(java.lang);
importPackage(java.util);
importPackage(Packages.com.silverwrist.venice.core);
importPackage(Packages.com.silverwrist.venice.except);
importPackage(Packages.com.silverwrist.venice.ui);
importPackage(Packages.com.silverwrist.venice.ui.conf);
importPackage(Packages.com.silverwrist.venice.ui.helpers);
importPackage(Packages.com.silverwrist.venice.ui.view);

// get the request object and the community
rinput = bsf.lookupBean("request");
comm = rinput.getCommunity(true,"top.js.vs");

// get the current conference
currc = new CurrentConference(rinput);
conf = currc.getConference(true,"conf/conferences.js.vs?cc=" + comm.communityID);
on_error = "conf/manage_conf.js.vs?cc=" + comm.communityID + "&conf=" + conf.confID;

if (!(conf.canChangeConference()))
{ // you can't fiddle with this conference
  vlib.output(new ErrorBox("Access Error","You do not have permission to export posts from this conference.",
                           on_error));
  vlib.done();

} // end if

rc = null;  // return from this script
try
{ // figure out what to do here
  if ("GET"==rinput.verb)
  { // load and display the JSP page for the form
    l = conf.getTopicList(ConferenceContext.GET_ALL,ConferenceContext.SORT_NUMBER);
    rinput.setRequestAttribute("topic.list",l);

    rc = new JSPView("Export Messages: " + conf.name,"conf/export.jsp");
    rc.menuSelector = Content.MENU_SELECTOR_COMMUNITY;

  } // end if
  else  // POST
  { // get the parameters and generate the export file
    if (rinput.isImageButtonClicked("cancel"))
      rc = new Redirect(on_error,LinkTypes.SERVLET);  // cancel - go back to menu
    else if (rinput.isImageButtonClicked("export"))
    { // get the list of topics to be exported
      tarray = rinput.getParameterValues("tselect");
      if (tarray==null)
        rc = new ErrorBox("Input Error","No topics selected.",on_error);
      else if (tarray.length==0)
        rc = new ErrorBox("Input Error","No topics selected.",on_error);
      else
      { // convert the array of string equivalent topic numbers to a set of topic indexes
        tset = new HashSet();
        for (i=0; i<tarray.length; i++)
          tset.add(new Integer(tarray[i]));

        // generate the XML output
        xout = conf.exportTopics(tset);
        rc = new AttachmentContent(xout,"text/xml","exported-data.xml");

      } // end else
      
    } // end else if
    else
    { // invalid command button pressed
      logger.error("no known button click on POST to conf/export.js");
      rc = new ErrorBox("Internal Error","Unknown command button pressed",on_error);

    } // end else

  } // end else

} // end try
catch (e)
{ // figure out exception type
  etype = vlib.exceptionType(e) + "";
  if (etype.match("AccessError"))
    rc = new ErrorBox("Access Error",e.message,on_error);
  else if (etype.match("DataException"))
    rc = new ErrorBox("Database Error",e.message,on_error);
  else if (etype.match("IOException"))
    rc = new ErrorBox("I/O Error",e.message,on_error);
  else
    rc = e;
  
} // end catch

vlib.output(rc);
